@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Codec.Archive.Tar
@@ -28,8 +29,16 @@ import qualified System.FilePath as FilePath.Native
 import System.Directory
          ( getDirectoryContents, doesDirectoryExist, getModificationTime
          , Permissions(..), getPermissions )
+#if MIN_VERSION_directory(1,2,0)
+-- The directory package switched to the new time package
+import Data.Time.Clock
+         ( UTCTime )
+import Data.Time.Clock.POSIX
+         ( utcTimeToPOSIXSeconds )
+#else
 import System.Time
          ( ClockTime(..) )
+#endif
 import System.IO
          ( IOMode(ReadMode), openBinaryFile, hFileSize )
 import System.IO.Unsafe (unsafeInterleaveIO)
@@ -170,5 +179,11 @@ recurseDirectories base (dir:dirs) = unsafeInterleaveIO $ do
 
 getModTime :: FilePath -> IO EpochTime
 getModTime path = do
+#if MIN_VERSION_directory(1,2,0)
+  -- The directory package switched to the new time package
+  t <- getModificationTime path
+  return . floor . utcTimeToPOSIXSeconds $ t
+#else
   (TOD s _) <- getModificationTime path
   return $! fromIntegral s
+#endif
